.. _contribute:

Contribute to Falcon
====================

Thanks for your interest in the project! We welcome pull requests from
developers of all skill levels. To get started, simply fork the master branch
on GitHub to your personal account and then clone the fork into your
development environment.

Kurt Griffiths (**kgriffs** on GH, Gitter, and Twitter) is the original
creator of the Falcon framework, and currently co-maintains the project
along with John Vrbanac (**jmvrbanac** on GH and Gitter, and
**jvrbanac** on Twitter). Falcon is developed by a growing community of
users and contributors just like you.

Please don't hesitate to reach out if you have any questions, or just need a
little help getting started. You can find us in
`falconry/dev <https://gitter.im/falconry/dev>`_ on Gitter.

Please check out our
`Contributor's Guide <https://github.com/falconry/falcon/blob/master/CONTRIBUTING.md>`_
for more information.

Thanks!
